OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Hatalı parola",
    "The new password can not be the same as the previous one" : "Yeni parola eskisiyle aynı olamaz",
    "No user supplied" : "Kullanıcı girilmedi",
    "Authentication error" : "Kimlik doğrulama hatası",
    "Wrong admin recovery password. Please check the password and try again." : "Hatalı yönetici kurtarma parolası. Lütfen parolayı denetleyip yeniden deneyin.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Arka uç, parola değiştirmesini desteklemiyor, ancak kullanıcı şifreleme anahtarı başarıyla güncellendi.",
    "Unable to change password" : "Parola değiştirilemiyor",
    "Couldn't send reset email. Please contact your administrator." : "Sıfırlama e-postası gönderilemedi. Lütfen yöneticiniz ile iletişime geçin.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "uygulama mağazası ve Birleşmiş Bulut Paylaşımından uygulama kurma ve güncelleme",
    "Federated Cloud Sharing" : "Birleşmiş Bulut Paylaşımı",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL eskide kalmış bir sürüm %s kullanıyor (%s). Lütfen işletim sisteminizi güncelleyin, aksi halde %s gibi özellikler düzgün çalışmayacaktır.",
    "A problem occurred, please check your log files (Error: %s)" : "Bir problem oluştu, lütfen log dosyalarını kontrol edin (Hata: %s)",
    "Migration Completed" : "Taşınma Tamamlandı",
    "Group already exists." : "Grup zaten mevcut.",
    "Unable to add group." : "Grup ekleme başarısız.",
    "Unable to delete group." : "Grubu silme başarısız.",
    "log-level out of allowed range" : "günlük seviyesi izin verilen aralık dışında",
    "Saved" : "Kaydedildi",
    "test email settings" : "e-posta ayarlarını sına",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "E-posta gönderilirken bir hata oluştu. Lütfen ayarlarınızı gözden geçirin. (Hata: %s)",
    "Email sent" : "E-posta gönderildi",
    "You need to set your user email before being able to send test emails." : "Sınama e-postaları göndermeden önce kullanıcı e-postasını ayarlamanız gerekiyor.",
    "Invalid mail address" : "Geçersiz posta adresi",
    "A user with that name already exists." : "Bu isimde bir kullanıcı adı zaten mevcut.",
    "Unable to create user." : "Kullanıcı oluşturma başarısız.",
    "Your %s account was created" : "%s hesabınız oluşturuldu",
    "Unable to delete user." : "Kullanıcı silme başarısız.",
    "Forbidden" : "Yasaklı",
    "Invalid user" : "Geçersiz kullanıcı",
    "Unable to change mail address" : "Posta adresini değiştirme başarısız",
    "Your full name has been changed." : "Tam adınız değiştirildi.",
    "Unable to change full name" : "Tam adınız değiştirilirken hata",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "Türkçe",
    "Language changed" : "Dil değiştirildi",
    "Invalid request" : "Geçersiz istek",
    "Admins can't remove themself from the admin group" : "Yöneticiler kendilerini admin grubundan kaldıramaz",
    "Unknown user" : "Bilinmeyen kullanıcı",
    "Couldn't remove app." : "Uygulama kaldırılamadı.",
    "Official" : "Resmi",
    "Approved" : "Onaylanmış",
    "All" : "Tümü",
    "Enabled" : "Etkin",
    "Not enabled" : "Etkin değil",
    "No apps found for your version" : "Sürümünüz için uygulama bulunamadı",
    "The app will be downloaded from the app store" : "Uygulama uygulama mağazasından indirilebilecek",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Resmi uygulamalar ownCloud topluluğu tarafından geliştirilir. ownCloud'a işlevsellik merkezli olarak hazırlanırlar ve günlük kullanıma hazırdırlar.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Onaylanan uygulamalar güvenilir geliştiriciler tarafından geliştirilir ve detaylı olmayan bir güvenlik kontrolünden geçirilir. Bunlar açık kaynak kod deposunda bulunmakta ve normal kullanım için kararlı oldukları varsayılmaktadır.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Bu uygulama güvenlik kontrolünden geçmedi veya yeni ya da kararsız olarak bilinmektedir. Kendiniz bu riski alarak yükleyebilirsiniz.",
    "Please wait...." : "Lütfen bekleyin....",
    "Error while disabling app" : "Uygulama devre dışı bırakılırken hata",
    "Disable" : "Devre Dışı Bırak",
    "Enable" : "Etkinleştir",
    "Error while enabling app" : "Uygulama etkinleştirilirken hata",
    "Error: this app cannot be enabled because it makes the server unstable" : "Hata: bu uygulama etkinleştirilemez çünkü sunucuyu kararsız yapıyor",
    "Error: could not disable broken app" : "Hata: bozuk uygulama devre dışı bırakılamadı",
    "Error while disabling broken app" : "Bozuk uygulama devre dışı bırakılırken hata",
    "Updating...." : "Güncelleniyor....",
    "Error while updating app" : "Uygulama güncellenirken hata",
    "Updated" : "Güncellendi",
    "Uninstalling ...." : "Kaldırılıyor ....",
    "Error while uninstalling app" : "Uygulama kaldırılırken hata",
    "Uninstall" : "Kaldır",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Uygulama etkinleştirildi fakat güncellenmesi gerekiyor. 5 saniye içinde güncelleme sayfasına yönlendirileceksiniz.",
    "App update" : "Uygulama güncellemesi",
    "Experimental" : "Deneysel",
    "No apps found for {query}" : "{query} sorgusu için hiçbir uygulama yok",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "\"{domain}\" alan adını güvenilir alan adı olarak eklemek istediğinizden emin misiniz?",
    "Add trusted domain" : "Güvenilir alan adı ekle",
    "Migration in progress. Please wait until the migration is finished" : "Taşınma sürüyor. Lütfen taşınma tamamlanana kadar bekleyin",
    "Migration started …" : "Taşınma başladı ...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Bir hata oluştu. Lütfen ASCII-kodlanmış PEM sertifikasını yükleyin.",
    "Valid until {date}" : "{date} tarihine kadar geçerli",
    "Delete" : "Sil",
    "Disconnect" : "Bağlantıyı kes",
    "Error while loading browser sessions and device tokens" : "Tarayıcı oturumlarını ve aygıt jetonlarını yüklerken hata oluştu",
    "Error while creating device token" : "Aygıt jetonunun oluşturulmasında hata oluştu",
    "Error while deleting the token" : "Jeton silinirken hata oluştu",
    "Sending..." : "Gönderiliyor...",
    "An error occurred: {message}" : "Bir hata oluştu: {message}",
    "Select a profile picture" : "Bir profil fotoğrafı seçin",
    "Very weak password" : "Çok güçsüz parola",
    "Weak password" : "Güçsüz parola",
    "So-so password" : "Normal parola",
    "Good password" : "İyi parola",
    "Strong password" : "Güçlü parola",
    "Groups" : "Gruplar",
    "Unable to delete {objName}" : "{objName} silinemiyor",
    "Error creating group: {message}" : "Grup oluşturulurken hata: {message}",
    "A valid group name must be provided" : "Geçerli bir grup adı mutlaka sağlanmalı",
    "deleted {groupName}" : "{groupName} silindi",
    "undo" : "geri al",
    "never" : "hiçbir zaman",
    "deleted {userName}" : "{userName} silindi",
    "add group" : "grup ekle",
    "Invalid quota value \"{val}\"" : "Geçersiz kalan alan değeri \"{val}\"",
    "enabled" : "etkin",
    "disabled" : "devre dışı",
    "no group" : "grup yok",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Parolayı değiştirmek, bu kullanıcı için veri kurtarması kullanılamadığından veri kaybına sebep olacak",
    "Password successfully changed" : "Şifre başarıyla değiştirildi.",
    "A valid username must be provided" : "Geçerli bir kullanıcı adı mutlaka sağlanmalı",
    "Error creating user: {message}" : "Kullanıcı oluşturulurken hata: {message}",
    "A valid password must be provided" : "Geçerli bir parola mutlaka sağlanmalı",
    "A valid email must be provided" : "Geçerli bir e-posta belirtilmeli",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Merhaba,<br><br>Sadece artık bir %s hesabınızın olduğunu söylemek istedim.<br><br>Kullanıcı adınız: %s<br>Şuradan erişin: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Hoşçakalın!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Merhaba,\n\nSadece, artık bir %s hesabınızın olduğunu söylemek istedim.\n\nKullanıcı adınız: %s\nErişim: %s\n\n",
    "User documentation" : "Kullanıcı belgelendirmesi",
    "Administrator documentation" : "Yönetici belgelendirmesi",
    "Online documentation" : "Çevrimiçi belgelendirme",
    "Forum" : "Forum",
    "Issue tracker" : "Sorun izleyici",
    "Commercial support" : "Ticari destek",
    "Developer documentation" : "Geliştirici belgelendirmesi",
    "by %s" : "Yazar: %s",
    "%s-licensed" : "%s lisanslı",
    "Documentation:" : "Belgelendirme:",
    "Admin documentation" : "Yönetici belgelendirmesi",
    "Visit website" : "Web sayfasını ziyaret et",
    "Report a bug" : "Bir hata raporlayın",
    "Show description …" : "Açıklamayı göster...",
    "Hide description …" : "Açıklamayı gizle...",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Bu uygulama atanmış bir en düşük ownCloud sürümü içermiyor. ownCloud 11 ve sonrasında bu bir hata olacaktır.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Bu uygulama atanmış bir en yüksek ownCloud sürümü içermiyor. ownCloud 11 ve sonrasında bu bir hata olacaktır.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Bu uygulama, aşağıdaki bağımlılıklar sağlanmadığından yüklenemiyor:",
    "Enable only for specific groups" : "Sadece belirli gruplar için etkinleştir",
    "Uninstall App" : "Uygulamayı Kaldır",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Son cron çalıştırılma: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Son cron çalıştırılma: %s. Bir şeyler yanlış gibi görünüyor.",
    "Cron was not executed yet!" : "Cron henüz çalıştırılmadı!",
    "Open documentation" : "Belgelendirmeyi aç",
    "Execute one task with each page loaded" : "Yüklenen her sayfa ile bir görev çalıştır",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php, http üzerinden her 15 dakikada bir çağrılması için webcron hizmetine kaydedilir.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Cron.php dosyasını her 15 dakikada bir çağırmak için sistem cron hizmetini kullan.",
    "SSL Root Certificates" : "SSL Kök Sertifikaları",
    "Common Name" : "Ortak Ad",
    "Valid until" : "Geçerlilik",
    "Issued By" : "Veren",
    "Valid until %s" : "%s tarihine kadar geçerli",
    "Import root certificate" : "Kök sertifikalarını içe aktar",
    "Server-side encryption" : "Sunucu taraflı şifreleme",
    "Enable server-side encryption" : "Sunucu taraflı şifrelemeyi aç",
    "Please read carefully before activating server-side encryption: " : "Lütfen sunucu tarafında şifrelemeyi etkinleştirmeden önce dikkatlice okuyun: ",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Şifreleme etkinleştirildiğinde, sunucuya yüklenen tüm dosyalar şifrelenmiş olarak kalacaktır. Şifrelemeyi devre dışı bırakmak sadece ileriki zamanlarda aktif şifreleme modülü desteklediğinde ve ön koşullar (örn: düzenleme anahtarı oluşturulması) yerine getirildiğinde yapılabilir.",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Şifreleme tek başına sistem güvenliğini garanti etmez. Lütfen şifreleme uygulamasının çalışma bilgisi ve desteklenen kullanım durumları için ownCloud belgelerine bakın.",
    "Be aware that encryption always increases the file size." : "Şifrelemenin dosya boyutunu büyüteceğini unutmayın.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Verilerinizi düzenli yedekleyin ve şifreleme anahtarlarınızın verilerinizle birlikte yedeklendiğinden emin olun. ",
    "This is the final warning: Do you really want to enable encryption?" : "Bu son uyarıdır: Şifrelemeyi etkinleştirmek istiyor musunuz?",
    "Enable encryption" : "Şifrelemeyi aç",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Hiç şifrelenme modülü yüklenmemiş, lütfen uygulama menüsünden bir şifreleme modülü etkinleştirin.",
    "Select default encryption module:" : "Öntanımlı şifreleme modülünü seçin:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Eski şifreleme anahtarlarınızı eski şifrelemeden (ownCloud <= 8.0) yenisine taşımanız gerekli. Lütfen \"Öntanımlı şifreleme modülü\"nü etkinleştirin ve 'occ encryption:migrate' çalıştırın",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Eski şifreleme anahtarlarınızı eski şifrelemeden (ownCloud <= 8.0) yenisine taşımanız gerekli.",
    "Start migration" : "Taşınmayı başlat",
    "Sharing" : "Paylaşım",
    "Allow apps to use the Share API" : "Uygulamaların paylaşım API'sini kullanmasına izin ver",
    "Allow users to share via link" : "Kullanıcıların bağlantı ile paylaşmasına izin ver",
    "Allow public uploads" : "Herkes tarafından yüklemeye izin ver",
    "Enforce password protection" : "Parola korumasını zorla",
    "Set default expiration date" : "Öntanımlı son kullanma tarihini ayarla",
    "Allow users to send mail notification for shared files" : "Paylaşılmış dosyalar için kullanıcıların posta bildirimi göndermesine izin ver",
    "Expire after " : "Süre",
    "days" : "gün sonra dolsun",
    "Enforce expiration date" : "Son kullanma tarihini zorla",
    "Allow resharing" : "Yeniden paylaşıma izin ver",
    "Allow sharing with groups" : "Grouplar ile paylaşıma izin ver",
    "Restrict users to only share with users in their groups" : "Kullanıcıların, dosyaları sadece kendi gruplarındaki kullanıcılarla paylaşmasına izin ver",
    "Allow users to send mail notification for shared files to other users" : "Kullanıcıların diğer kullanıcılara, paylaşılmış dosyalar için posta bildirimi göndermesine izin ver",
    "Exclude groups from sharing" : "Grupları paylaşma eyleminden hariç tut",
    "These groups will still be able to receive shares, but not to initiate them." : "Bu gruplar hala paylaşımları alabilecek, ancak başlatamayacaktır.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Paylaşma iletişim kutusunda kullanıcı adı otomatik tamamlamasını etkinleştir. Devre dışı olduğunda tam kullanıcı adı girilmeli.",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Her şey (Ciddi sorunlar, hatalar, uyarılar, bilgi, hata ayıklama)",
    "Info, warnings, errors and fatal issues" : "Bilgi, uyarılar, hatalar ve ciddi sorunlar",
    "Warnings, errors and fatal issues" : "Uyarılar, hatalar ve ciddi sorunlar",
    "Errors and fatal issues" : "Hatalar ve ciddi sorunlar",
    "Fatal issues only" : "Sadece ciddi sorunlar",
    "Log" : "Günlük",
    "What to log" : "Neler günlüklenmeli",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Günlük dosyası 100 MB'dan daha büyük. İndirmek zaman alabilir!",
    "None" : "Hiçbiri",
    "Login" : "Oturum Aç",
    "Plain" : "Düz",
    "NT LAN Manager" : "NT Ağ Yöneticisi",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "E-posta sunucusu",
    "This is used for sending out notifications." : "Bu, bildirimler gönderilirken kullanılır.",
    "Send mode" : "Gönderme kipi",
    "Encryption" : "Şifreleme",
    "From address" : "Kimden adresi",
    "mail" : "posta",
    "Authentication method" : "Kimlik doğrulama yöntemi",
    "Authentication required" : "Kimlik doğrulama gerekli",
    "Server address" : "Sunucu adresi",
    "Port" : "Port",
    "Credentials" : "Kimlik Bilgileri",
    "SMTP Username" : "SMTP Kullanıcı Adı",
    "SMTP Password" : "SMTP Parolası",
    "Store credentials" : "Kimlik bilgilerini depola",
    "Test email settings" : "E-posta ayarlarını sına",
    "Send email" : "E-posta gönder",
    "Security & setup warnings" : "Güvenlik ve kurulum uyarıları",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP sistem değişkenleri sorgusuna uygun olarak ayarlanmamış görünüyor. getenv(\"PATH\") komutu sadece boş bir cevap döndürüyor.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Lütfen php yapılandırma notları ve özellikler php-fpm kullanırken sunucu php yapılandırması için <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">kurulum belgelendirmesine ↗</a> bakın.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Salt Okunur yapılandırma etkinleştirilmiş. Bu, bazı ayarların web arayüzü ile yapılandırılmasını önler. Ayrıca, bu dosya her güncelleme sırasında el ile yazılabilir yapılmalıdır.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP satırıçi doc bloklarını ayıklamak üzere yapılandırılmış gibi görünüyor. Bu, bazı çekirdek (core) uygulamalarını erişilemez yapacak.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Bu, muhtemelen Zend OPcache veya eAccelerator gibi bir önbellek/hızlandırıcı nedeniyle gerçekleşir.",
    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Veritabanınız \"READ COMMITED\" soyutlama seviyesi ile çalışmıyor. Bu paralel eylemler çalıştığında sorunlara yol açabilir.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s, %2$s sürümü altı kurulu. Kararlılık ve performans için daha yeni bir %1$s sürümüne güncellemenizi öneririz.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP modülü 'fileinfo' kayıp. MIME türü tanıma ile en iyi sonuçları elde etmek için bu modülü etkinleştirmenizi öneririz.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "İşlemsel dosya kilidi devre dışı. Bu yarış koşulu (race condition) sorunlarına neden olabilir. Bu sorunlardan kaçınmak için config.php içindeki 'filelocking.enabled' ayarını etkinleştirin. Daha fazla bilgi için <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">belgelendirmeye ↗</a> bakın.",
    "System locale can not be set to a one which supports UTF-8." : "Sistem yereli, UTF-8 destekleyenlerden biri olarak ayarlanamadı.",
    "This means that there might be problems with certain characters in file names." : "Bu, dosya adlarında belirli karakterlerde problem olabileceği anlamına gelir.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Şu dillerden birini desteklemesi için sisteminize gerekli paketleri kurmanızı şiddetle tavsiye ederiz: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Eğer kurulumunuz alan adının köküne yapılmamışsa ve sistem cron'u kullanıyorsa, URL oluşturma ile ilgili sorunlar oluşabilir. Bu sorunların önüne geçmek için, kurulumunuzun web kök yolundaki config.php dosyasında \"overwrite.cli.url\" seçeneğini ayarlayın (Önerilen: \"%s\")",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Veritabanı olarak SQLite kullanılıyor. Daha büyük kurulumlar için farklı bir veritabanı arka ucuna geçmenizi öneriyoruz.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Özellikle dosya eşitleme için masaüstü istemcisi kullanılırken SQLite kullanımı önerilmez.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Başka bir veritabanına geçmek için komut satırı aracını kullanın: 'occ db:convert-type' veya <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">belgelendirmeye ↗</a> bakın.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Bu CLI ile cronjobı çalıştırmak mümkün değildi. Aşağıdaki teknik hatalar ortaya çıkmıştır:",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Lütfen <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">kurulum rehberlerine ↗</a> ve <a href=\"#log-section\">günlük</a> kısmındaki hata ve uyarılara bakın.",
    "All checks passed." : "Tüm kontroller geçildi.",
    "Tips & tricks" : "İpuçları ve hileler",
    "How to do backups" : "Nasıl yedekleme yapılır",
    "Advanced monitoring" : "Gelişmiş izleme",
    "Performance tuning" : "Performans ayarlama",
    "Improving the config.php" : "config.php iyileştirme",
    "Theming" : "Tema",
    "Hardening and security guidance" : "Sağlamlaştırma ve güvenlik rehberliği",
    "Get the apps to sync your files" : "Dosyalarınızı eşitlemek için uygulamaları indirin",
    "Desktop client" : "Masaüstü istemcisi",
    "Android app" : "Android uygulaması",
    "iOS app" : "iOS uygulaması",
    "Show First Run Wizard again" : "İlk Çalıştırma Sihirbazı'nı yeniden göster",
    "Profile picture" : "Profil resmi",
    "Upload new" : "Yeni yükle",
    "Select from Files" : "Dosyalardan seç",
    "Remove image" : "Resmi kaldır",
    "png or jpg, max. 20 MB" : "png veya jpg, azami 20 MB",
    "Picture provided by original account" : "Görüntü resminiz, özgün hesabınız tarafından sağlanıyor.",
    "Cancel" : "İptal",
    "Choose as profile picture" : "Profil resmi olarak seç",
    "Full name" : "Ad soyad",
    "No display name set" : "Ekran adı ayarlanmamış",
    "Email" : "E-posta",
    "Your email address" : "E-posta adresiniz",
    "For password recovery and notifications" : "Parola kurtarma ve bildirimler için",
    "No email address set" : "E-posta adresi ayarlanmamış",
    "You are member of the following groups:" : "Şu grupların üyesisiniz:",
    "Password" : "Parola",
    "Unable to change your password" : "Parolanız değiştirilemiyor",
    "Current password" : "Mevcut parola",
    "New password" : "Yeni parola",
    "Change password" : "Parola değiştir",
    "Language" : "Dil",
    "Help translate" : "Çevirilere yardım edin",
    "Unlimited" : "Sınırsız",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "{communityopen}ownCloud topluluğu tarafından{linkclose} geliştirildi. {githubopen}Kaynak kodu{linkclose}, {licenseopen}<abbr title=\"Affero Genel Kamu Lisansı\">AGPL</abbr>{linkclose} ile lisanslanmıştır.",
    "Sessions" : "Oturumlar",
    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Bunlar ownCloud'unuza halen bağlı olan web, masaüstü ve mobil istemcileridir.",
    "Browser" : "Tarayıcı",
    "Most recent activity" : "Son güncel etkinlik",
    "App passwords" : "Uygulama parolaları",
    "You've linked these apps." : "Bu uygulamaları bağladınız.",
    "Name" : "Ad",
    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Bir uygulama parolası %s hesabınıza erişim için izin verdiğiniz uygulama veya aygıtın giriş kodudur.",
    "App name" : "Uygulama adı",
    "Create new app password" : "Yeni uygulama parolası oluştur",
    "Use the credentials below to configure your app or device." : "Uygulama veya aygıtı yapılandırmak için aşağıdaki kimlik bilgilerini kullan.",
    "Username" : "Kullanıcı Adı",
    "Done" : "Bitti",
    "Version" : "Sürüm",
    "Personal" : "Kişisel",
    "Admin" : "Yönetici",
    "Error" : "Hata",
    "Show storage location" : "Depolama konumunu göster",
    "Show last log in" : "Son oturum açılma zamanını göster",
    "Show user backend" : "Kullanıcı arka ucunu göster",
    "Send email to new user" : "Yeni kullanıcıya e-posta gönder",
    "Show email address" : "E-posta adresini göster",
    "E-Mail" : "E-Posta",
    "Create" : "Oluştur",
    "Admin Recovery Password" : "Yönetici Kurtarma Parolası",
    "Enter the recovery password in order to recover the users files during password change" : "Parola değiştirme sırasında kullanıcı dosyalarını kurtarmak için kurtarma parolasını girin",
    "Add Group" : "Grup Ekle",
    "Group" : "Grup",
    "Everyone" : "Herkes",
    "Admins" : "Yöneticiler",
    "Default Quota" : "Öntanımlı Kota",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Lütfen disk alanı kotasını girin (örnek: \"512MB\" veya \"12GB\")",
    "Other" : "Diğer",
    "Full Name" : "Tam Adı",
    "Group Admin for" : "Grup Yöneticisi",
    "Quota" : "Kota",
    "Storage Location" : "Depolama Konumu",
    "User Backend" : "Kullanıcı Arka Ucu",
    "Last Login" : "Son Giriş",
    "change full name" : "tam adı değiştir",
    "set new password" : "yeni parola belirle",
    "change email address" : "e-posta adresini değiştir",
    "Default" : "Öntanımlı",
    "Change" : "Değiştir",
    "Share" : "Paylaş",
    "Domain" : "Alan adı",
    "Add" : "Ekle",
    "%s password changed successfully" : "%s parola başarıyla değiştirildi"
},
"nplurals=2; plural=(n > 1);");
